@@ -31,13 +31,14 @@ import shutil
 import time
 import threading
 
+
 class LowBar:
 
     """
     The main lowbar class.
     """
 
-    def __init__(self, bar_load_fill: str="#", bar_blank_fill: str="-") -> None:
+    def __init__(self, bar_iter: object=None, smooth_iter: bool=False, bar_load_fill: str="#", bar_blank_fill: str="-") -> None:
 
         """
         Initializes a few variables.
@@ -49,6 +50,8 @@ class LowBar:
         if not isinstance(bar_blank_fill, str):
             raise TypeError("arg bar_blank_fill should be type str")
 
+        self.bar_iter: object = bar_iter
+        self.smooth_iter: bool = smooth_iter
         self.completion: int = 1
         self.bar_load_fill: str = bar_load_fill
         self.bar_blank_fill: str = bar_blank_fill
@@ -58,23 +61,42 @@ class LowBar:
 
         """
         Context manager setup to automatically display bar
-        without requiring update().
+        without requiring new().
         """
 
-        self.update(0)
+        self.new()
 
         return self
 
-    def __exit__(self, type, value, traceback) -> None:
+    def __exit__(self, *exc) -> None:
 
         """
         Context manager exit to clear the bar automatically
         without requiring clear().
         """
 
-        self._block_when_smoothing()
+        self.clear()
 
-        self._overwrite_bar()
+    def __iter__(self) -> object:
+
+        """
+        Iterable manager that automatically runs new() at the
+        start and clear() at the end
+        """
+
+        self.new()
+
+        div: float = 100 / len(list(self.bar_iter))
+        add: float = div
+
+        try:
+            for item in self.bar_iter:
+                yield item
+                self.update(int(div)) if not self.smooth_iter else self.update_smooth(int(div))
+                div += add
+
+        finally:
+            self.clear()
 
     def _print_internal(self, text: str) -> None:
 
@@ -95,7 +117,8 @@ class LowBar:
     def _update_bar(self) -> None:
 
         """
-        Refreshes the current bar with new values.
+        Refreshes the current bar with new values, and a
+        possibly resized console.
         """
 
         completion_string: str = f" {str(self.completion)}" if self.completion < 10 else str(self.completion)
@@ -113,7 +136,7 @@ class LowBar:
         overwrite: str = (" " * (self._get_terminal_columns() - len(text)))
         self._print_internal(f"\r{text}{overwrite}")
 
-    def _update_bar_smooth(self, percentage: int):
+    def _update_bar_smooth(self, percentage: int) -> None:
 
         """
         Wraps _update_bar() with a smoother but slower animation.
@@ -129,7 +152,7 @@ class LowBar:
 
         self.bar_is_smoothing = False
 
-    def _block_when_smoothing(self):
+    def _block_when_smoothing(self) -> None:
 
         """
         Blocks the main thread if bar is still running _update_bar_smooth()
@@ -157,7 +180,15 @@ class LowBar:
         self.completion = percentage
         self._update_bar()
 
-    def update_smooth(self, percentage: int):
+    def new(self) -> None:
+
+        """
+        Alias for update(0)
+        """
+
+        self.update(0)
+
+    def update_smooth(self, percentage: int) -> None:
 
         """
         Increases the completed percentage and calls _update_bar_smooth()
